@@ -5,8 +5,8 @@ from datetime import datetime, timedelta
 class random_timeout:
     '''Random timeout between minimum and maximum values'''
     def __init__(self, minimum, maximum):
-        if minimum == 0:
-            minimum += random()
+        if minimum <= 0:
+            minimum = random()
         else:
             minimum -= random() # Random float between 0 and 1
         maximum += random()
@@ -23,7 +23,6 @@ class random_timeout:
             print('Sleeping', timeout_in_minutes, 'minutes until', til)
         sleep(timeout_in_seconds)
 
-
 class sleep_for:
     '''Sleep amount of time in minutes, prints when it will continue'''
     def __init__(self, minutes):
